@@ -28,7 +28,7 @@ from libopensesame.exceptions import osexception
 from openexp.keyboard import keyboard
 import wave
 
-VERSION = u'8.3.0'
+VERSION = u'8.4.0'
 
 class audio_low_latency_play(item):
 
@@ -215,11 +215,10 @@ class audio_low_latency_play(item):
 
             self.show_message(u'Initializing audio playback')
 
-            if self.ram_cache == u'No':
-                self.play_file(self.device, self.wav_file, self.period_size, delay)
+            if self.ram_cache == u'no':
+                self.play(self.device, self.wav_file, self.period_size, delay)
             elif self.ram_cache == u'yes':
-                self.play_data(self.device, self.wav_file_data, self.data_size, delay)
-
+                self.play(self.device, self.wav_file, self.data_size, delay, self.wav_file_data)
 
         elif self.dummy_mode == u'yes':
             self.set_stimulus_onset()
@@ -228,10 +227,17 @@ class audio_low_latency_play(item):
             raise osexception(u'Error with dummy mode!')
 
 
-    def play_file(self, stream, wav_file, chunk, delay):
+    def play(self, stream, wav_file, chunk, delay, wav_data=None):
 
-        # Read data from wave
-        data = wav_file.readframes(chunk)
+        start = 0
+
+        if self.ram_cache == u'no':
+            # Read data from wave
+            data = wav_file.readframes(chunk)
+        elif self.ram_cache == u'yes':
+            data = wav_data[start:start+chunk]
+
+        self.show_message(u'Chunk size: %d bytes' % (len(data)))
 
         if self.delay_check:
             if delay >= 1:
@@ -248,8 +254,16 @@ class audio_low_latency_play(item):
             # write data to device
             stream.write(data)
 
-            # Read data from wave
-            data = wav_file.readframes(chunk)
+            if self.ram_cache == u'no':
+                # Read data from wave
+                data = wav_file.readframes(chunk)
+            elif self.ram_cache == u'yes':
+                if len(wav_data) >= start+chunk:
+                    data = wav_data[start:start+chunk]
+                elif len(wav_data) < start+chunk:
+                    data = wav_data[start:len(wav_data)]
+
+                start += chunk
 
             # check for stop/pause/resume key
             if self.pause_resume != u'' or self.stop != u'':
@@ -263,61 +277,13 @@ class audio_low_latency_play(item):
                 break
             elif self.duration_check:
                 if self.clock.time() - start_time >= self.duration:
-                    break
-
-            if self.play_continue == 0:
-                break
-            elif self.duration_check:
-                if self.clock.time() - start_time >= self.duration:
-                    self.show_message(u'Audio stopped, duration exceeded')
+                    self.show_message(u'Audio playback stopped, duration exceeded')
                     break
 
         self.set_stimulus_offset()
 
-        wav_file.close()
-
-        self.show_message(u'Finished audio playback')
-
-
-    def play_data(self, stream, wav_data, chunk, delay):
-
-        if self.delay_check:
-            if delay >= 1:
-                self.show_message(u'Delaying audio playback for %d ms' % (delay))
-                self.clock.sleep(delay)
-                self.show_message(u'Delay done')
-
-        start_time = self.set_stimulus_onset()
-
-        self.show_message(u'Starting audio playback')
-
-        for start in range(0,len(wav_data),chunk):
-
-            # write data to device
-            stream.write(wav_data[start:start+chunk])
-
-            # check for stop/pause/resume key
-            if self.pause_resume != u'' or self.stop != u'':
-                self.check_keys()
-
-            while self.play_execute_pause == 1 and self.play_continue == 1:
-                if self.pause_resume != u'' or self.stop != u'':
-                    self.check_keys()
-
-            if self.play_continue == 0:
-                break
-            elif self.duration_check:
-                if self.clock.time() - start_time >= self.duration:
-                    break
-
-            if self.play_continue == 0:
-                break
-            elif self.duration_check:
-                if self.clock.time() - start_time >= self.duration:
-                    self.show_message(u'Audio stopped, duration exceeded')
-                    break
-
-        self.set_stimulus_offset()
+        if self.ram_cache == u'no':
+            wav_file.close()
 
         self.show_message(u'Finished audio playback')
 
